Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(10)

Unified Diff: test/codegen/expect/try_catch.js

Issue 1030063004: more care around generated names, fixes #60 #82 and #97 (Closed) Base URL: git@github.com:dart-lang/dev_compiler.git@master
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: test/codegen/expect/try_catch.js
diff --git a/test/codegen/expect/try_catch.js b/test/codegen/expect/try_catch.js
index 9ad17ef3a632d4cf824bc6822f71f2858da271ae..8a5d5b8c48a6597c9c2c36a9007c9c9f0c35eafd 100644
--- a/test/codegen/expect/try_catch.js
+++ b/test/codegen/expect/try_catch.js
@@ -1,21 +1,39 @@
var try_catch;
(function(exports) {
'use strict';
- // Function main: () → dynamic
- function main() {
+ // Function foo: () → dynamic
+ function foo() {
try {
throw "hi there";
- } catch ($e) {
- if (dart.is($e, core.String)) {
- let e = $e;
+ } catch (e$) {
+ if (dart.is(e$, core.String)) {
+ let e = e$;
+ let t = dart.stackTrace(e);
+ } else {
+ let e = e$;
let t = dart.stackTrace(e);
+ throw e;
}
- let e = $e;
+ }
+
+ }
+ // Function bar: () → dynamic
+ function bar() {
+ try {
+ throw "hi there";
+ } catch (e$) {
+ let e = e$;
let t = dart.stackTrace(e);
- throw e;
}
}
+ // Function main: () → dynamic
+ function main() {
+ foo();
+ bar();
+ }
// Exports:
+ exports.foo = foo;
+ exports.bar = bar;
exports.main = main;
})(try_catch || (try_catch = {}));

Powered by Google App Engine
This is Rietveld 408576698